@@ -1,11 +1,16 @@
 set.seed(123)
 
 data_sf <- head(memphis_robberies, 10)
-grid <- hotspot_grid(data_sf)
+grid <- hotspot_grid(data_sf, quiet = TRUE)
 data_df <- as.data.frame(sf::st_drop_geometry(data_sf))
 grid_df <- as.data.frame(sf::st_drop_geometry(grid))
-data_sf_empty <- data_sf
+data_sf_wrong_geo <- data_sf_all_empty <- data_sf_empty <- data_sf
 data_sf_empty$geometry[1] <- sf::st_point()
+data_sf_all_empty$geometry <- sf::st_sfc(sf::st_point())
+data_sf_wrong_geo$geometry[1] <- sf::st_cast(
+  data_sf_wrong_geo$geometry[1],
+  "LINESTRING"
+)
 data_sf_zero <- data_sf
 data_sf_zero$geometry[1] <- sf::st_point(x = c(0, 0))
 non_overlapping_grid <- sf::st_point(x = c(0, 0)) |>
@@ -30,7 +35,7 @@ test_that("error if `data` or `grid` are not SF objects of the correct type", {
   )
   expect_error(
     validate_inputs(data = data_sf, grid = grid_df, quiet = FALSE),
-    regexp = "either an SF object or `NULL`"
+    regexp = "must be an SF object or NULL"
   )
   expect_error(
     validate_inputs(
@@ -38,7 +43,11 @@ test_that("error if `data` or `grid` are not SF objects of the correct type", {
       grid = grid,
       quiet = FALSE
     ),
-    regexp = "SF object containing points"
+    regexp = "must be an SF object with POINT geometry"
+  )
+  expect_error(
+    validate_inputs(data = data_sf_wrong_geo, quiet = FALSE),
+    regexp = "must be an SF object with POINT geometry"
   )
   expect_error(
     validate_inputs(
@@ -46,14 +55,25 @@ test_that("error if `data` or `grid` are not SF objects of the correct type", {
       grid = sf::st_cast(grid, "LINESTRING"),
       quiet = FALSE
     ),
-    regexp = "SF object containing polygons or multipolygons"
+    regexp = "must be an SF object with POLYGON or MULTIPOLYGON geometry"
   )
 })
 
 test_that("error if `data` contains empty geometries", {
   expect_error(
     validate_inputs(data = data_sf_empty, grid = grid, quiet = FALSE),
-    regexp = "contains empty geometries"
+    regexp = "contains rows with missing geometry"
+  )
+  expect_error(
+    validate_inputs(data = data_sf_all_empty, grid = grid, quiet = FALSE),
+    regexp = "contains rows with missing geometry"
+  )
+})
+
+test_that("error if `data` and `grid` use different CRS", {
+  expect_error(
+    validate_inputs(data = data_sf, grid = sf::st_transform(grid, "EPSG:6538")),
+    "must use the same co-ordinate reference system"
   )
 })
 
@@ -76,7 +96,7 @@ test_that("error if `quiet` is not a single `TRUE` or `FALSE` value", {
 })
 
 test_that(
-  "error if `bandwidth` or `bandwidth_adjust` are of the wrong type or length",
+  "error if `bandwidth`/`bandwidth_adjust`/`cell_size` are wrong type/length",
   {
     expect_error(validate_bandwidth(bandwidth = "blah"))
     expect_error(validate_bandwidth(bandwidth = c(2, 3)))
@@ -84,6 +104,9 @@ test_that(
     expect_error(validate_bandwidth(adjust = "blah"))
     expect_error(validate_bandwidth(adjust = c(2, 3)))
     expect_error(validate_bandwidth(adjust = -1))
+    expect_error(validate_cell_size(cell_size = "blah"))
+    expect_error(validate_cell_size(cell_size = c(2, 3)))
+    expect_error(validate_cell_size(cell_size = -1))
   }
 )
 
@@ -96,6 +119,13 @@ test_that("Warning if `data` contain zero co-ordinates", {
   )
 })
 
+test_that("Warning if `bandwidth` is smaller than `cell_size` (#29)", {
+  expect_warning(
+    validate_bandwidth(bandwidth = 1, cell_size = 10, quiet = FALSE),
+    "Bandwidth is smaller than cell size"
+  )
+})
+
 
 
 # CHECK OUTPUTS
@@ -108,4 +138,6 @@ test_that("Result is an invisible `NULL` value", {
   expect_null(validate_inputs(data = data_sf, grid = grid, quiet = FALSE))
   expect_invisible(validate_bandwidth(bandwidth = 1))
   expect_null(validate_bandwidth(bandwidth = 1))
+  expect_invisible(validate_cell_size(cell_size = 1))
+  expect_null(validate_cell_size(cell_size = 1))
 })
